@@ -107,14 +107,14 @@ def getVisualStatus(status: int) -> str:
     NotPerformed = 'Cmd Ignored' if (status & Status.CmdNotPerformed) else ''
 
     Motor = 'Motor: '
-    if status & MotorStatus.Stopped:
-        Motor += 'Stopped'
-    elif status & MotorStatus.ConstantSpeed:
+    if status & MotorStatus.ConstantSpeed:
         Motor += 'Constant Speed'
     elif status & MotorStatus.Accelerating:
         Motor += 'Accelerating'
     elif status & MotorStatus.Decelerating:
         Motor += 'Decelerating'
+    else:
+        Motor += 'Stopped'
 
     Direction = 'Direction: '
     Direction += 'Forward' if (status & Constant.DirForward) else 'Reverse'
